@@ -6,7 +6,8 @@ from .interface import Interface
 
 class IReady(Interface, metaclass=ABCMeta):
     """The module can be in a "not ready" state for science and need to be initialized in some way."""
-    __module__ = 'pyobs.interfaces'
+
+    __module__ = "pyobs.interfaces"
 
     @abstractmethod
     async def is_ready(self, **kwargs: Any) -> bool:
@@ -18,4 +19,4 @@ class IReady(Interface, metaclass=ABCMeta):
         ...
 
 
-__all__ = ['IReady']
+__all__ = ["IReady"]
